@@ -26,6 +26,7 @@ import pip._internal.utils.misc
 # https://www.python.org/dev/peps/pep-0508/#environment-markers
 PY_VER = ".".join(map(str, sys.version_info[:2]))
 SYS_PLAT = sys.platform
+PLAT_SYS = platform.system()
 PLAT_PY_IMPL = platform.python_implementation()
 
 SBoarder = collections.namedtuple("SBoarder", ["boarders", "extrem", "extrem_op"])
@@ -140,6 +141,7 @@ def is_in_conditions(condition):
     return eval(
         condition.replace("sys_platform", '"%s"' % SYS_PLAT) \
                  .replace("python_version", '"%s"' % PY_VER) \
+                 .replace("platform_system", '"%s"' % PLAT_SYS) \
                  .replace("platform_python_implementation", '"%s"' % PLAT_PY_IMPL))
 
 def is_in_extra(extra, req_extra):
